diff --git a/spring-webflow/src/main/java/org/springframework/webflow/action/ExternalRedirectAction.java b/spring-webflow/src/main/java/org/springframework/webflow/action/ExternalRedirectAction.java
index a7f1fd06..b09c6a93 100644
--- a/spring-webflow/src/main/java/org/springframework/webflow/action/ExternalRedirectAction.java
+++ b/spring-webflow/src/main/java/org/springframework/webflow/action/ExternalRedirectAction.java
@@ -38,7 +38,7 @@ public class ExternalRedirectAction extends AbstractAction {
this.resourceUri = resourceUri;
}
- protected Event doExecute(RequestContext context) {
+ protected Event doExecute(RequestContext context) throws Exception {
String resourceUri = (String) this.resourceUri.getValue(context);
context.getExternalContext().requestExternalRedirect(resourceUri);
return success();
diff --git a/spring-webflow/src/main/java/org/springframework/webflow/action/FlowDefinitionRedirectAction.java b/spring-webflow/src/main/java/org/springframework/webflow/action/FlowDefinitionRedirectAction.java
index 6a465377..d1fcdae7 100644
--- a/spring-webflow/src/main/java/org/springframework/webflow/action/FlowDefinitionRedirectAction.java
+++ b/spring-webflow/src/main/java/org/springframework/webflow/action/FlowDefinitionRedirectAction.java
@@ -40,7 +40,7 @@ public class FlowDefinitionRedirectAction extends AbstractAction {
this.expression = expression;
}
- protected Event doExecute(RequestContext context) {
+ protected Event doExecute(RequestContext context) throws Exception {
String encodedRedirect = (String) expression.getValue(context);
if (encodedRedirect == null) {
throw new IllegalStateException(
diff --git a/spring-webflow/src/main/java/org/springframework/webflow/action/FormAction.java b/spring-webflow/src/main/java/org/springframework/webflow/action/FormAction.java
index 8531d6d2..9c0d9155 100644
--- a/spring-webflow/src/main/java/org/springframework/webflow/action/FormAction.java
+++ b/spring-webflow/src/main/java/org/springframework/webflow/action/FormAction.java
@@ -774,7 +774,7 @@ public class FormAction extends MultiAction implements InitializingBean {
* @see #initBinder(RequestContext, DataBinder)
* @see #setMessageCodesResolver(MessageCodesResolver)
*/
- protected DataBinder createBinder(RequestContext context, Object formObject) {
+ protected DataBinder createBinder(RequestContext context, Object formObject) throws Exception {
DataBinder binder = new WebDataBinder(formObject, getFormObjectName());
if (getMessageCodesResolver() != null) {
binder.setMessageCodesResolver(getMessageCodesResolver());
@@ -790,7 +790,7 @@ public class FormAction extends MultiAction implements InitializingBean {
* @param binder the data binder to use
* @throws Exception when an unrecoverable exception occurs
*/
- protected void doBind(RequestContext context, DataBinder binder) {
+ protected void doBind(RequestContext context, DataBinder binder) throws Exception {
if (logger.isDebugEnabled()) {
logger.debug("Binding allowed request parameters in "
+ StylerUtils.style(context.getExternalContext().getRequestParameterMap())
diff --git a/spring-webflow/src/main/java/org/springframework/webflow/action/SetAction.java b/spring-webflow/src/main/java/org/springframework/webflow/action/SetAction.java
index 32cf7c11..295ce308 100644
--- a/spring-webflow/src/main/java/org/springframework/webflow/action/SetAction.java
+++ b/spring-webflow/src/main/java/org/springframework/webflow/action/SetAction.java
@@ -51,7 +51,7 @@ public class SetAction extends AbstractAction {
this.valueExpression = valueExpression;
}
- protected Event doExecute(RequestContext context) {
+ protected Event doExecute(RequestContext context) throws Exception {
Object value = valueExpression.getValue(context);
nameExpression.setValue(context, value);
return success();
diff --git a/spring-webflow/src/main/java/org/springframework/webflow/action/AbstractAction.java b/spring-webflow/src/main/java/org/springframework/webflow/action/AbstractAction.java
index 08cd14bf..830d4422 100644
--- a/spring-webflow/src/main/java/org/springframework/webflow/action/AbstractAction.java
+++ b/spring-webflow/src/main/java/org/springframework/webflow/action/AbstractAction.java
@@ -52,7 +52,7 @@ public abstract class AbstractAction implements Action, InitializingBean {
return new EventFactorySupport();
}
- public void afterPropertiesSet() {
+ public void afterPropertiesSet() throws Exception {
try {
initAction();
} catch (Exception ex) {
@@ -66,7 +66,7 @@ public abstract class AbstractAction implements Action, InitializingBean {
* Keep in mind that this hook will only be invoked when this action is deployed in a Spring application context
* since it uses the Spring {@link InitializingBean} mechanism to trigger action initialisation.
*/
- protected void initAction() {
+ protected void initAction() throws Exception {
}
/**
@@ -217,7 +217,7 @@ public abstract class AbstractAction implements Action, InitializingBean {
* or null if the doExecute() method should be called to obtain the action result
* @throws Exception an unrecoverable exception occured, either checked or unchecked
*/
- protected Event doPreExecute(RequestContext context) {
+ protected Event doPreExecute(RequestContext context) throws Exception {
return null;
}
@@ -225,7 +225,7 @@ public abstract class AbstractAction implements Action, InitializingBean {
* Template hook method subclasses should override to encapsulate their specific action execution logic.
* @param context the action execution context, for accessing and setting data in "flow scope" or "request scope"
* @return the action result event
* @an unrecoverable exception occured, either checked or unchecked
*/
protected abstract Event doExecute(RequestContext context) throws Exception;
@@ -237,6 +237,6 @@ public abstract class AbstractAction implements Action, InitializingBean {
* @param context the action execution context, for accessing and setting data in "flow scope" or "request scope"
* @throws Exception an unrecoverable exception occured, either checked or unchecked
*/
- protected void doPostExecute(RequestContext context) {
+ protected void doPostExecute(RequestContext context) throws Exception {
}
}
@@ -225,7 +225,7 @@ public abstract class AbstractAction implements Action, InitializingBean {
* @param context the action execution context, for accessing and setting data in "flow scope" or "request scope"
* @return the action result event
- * @an unrecoverable exception occured, either checked or unchecked
+ * @throws Exception an unrecoverable exception occured, either checked or unchecked
*/
protected abstract Event doExecute(RequestContext context) throws Exception;